To choose whether to use postcss or tailwindcss, refer to [[Concept - Choosing watchers - postcss vs tailwindcss]]

---

Let's say you have a blank folder

Then you ran `npm init --y`.

And you created bare minimum:
```
.
├── package.json
└── public
    ├── index.css
    ├── index.html
```

^ You can quickly create the public/* files with these commands:
```
mkdir public; touch public/index.css; touch public/index.html;
```

This tutorial is a more detailed form of the official guide on using postcss:
https://tailwindcss.com/docs/installation/using-postcss

If tailwind is way ahead, then the URL might have migrated to (use this instead):
https://v4.tailwindcss.com/docs/installation/using-postcss

The official guide is missing many steps which could be a gotcha situation that stops you from setting up tailwind correctly. So just follow my guide.

---

Continuing...

1. Install Tailwind CSS and peer dependencies
```
npm install tailwindcss@4.1.3 @tailwindcss/postcss@4.1.3 postcss@8.5.3
```

Also install PostCSS CLI so that the npm script can build your target css file based on watching your html files for new tailwind classes:
```
npm install postcss-cli@11.0.1
```

Also install autoprefixer which helps with adding moz-and related vendor prefixes, so that the css rules in the styling classes work for older web browsers. This is a common practice with adding tailwind:
```
npm install autoprefixer@10.4.21
```


2. Add Tailwind and Autoprefixer to your PostCSS configuration
postcss.config.js was created after installing postcss. This is a configuration file that helps postcss transforms your css using plugins which have the transformation recipes.

Add the plugins tailwind and autoprefixer to `postcss.config.js` (You may need to create the file):
```
module.exports = {
  plugins: {
    "@tailwindcss/postcss": {},
    "autoprefixer": {},
  },
}
```


3. See where the source of your html files will be relative to your index.css file. In our case, it'll be "./". We will configure where to monitor for html and js changes for compiling new tailwind classes into the final css file. There is no tailwind.config.js in tailwind v4, and we can configure it as a directive at a css file! Go to next step.
   
4. Import Tailwind CSS
Import into the top of your index.css file (Tailwind v4 just uses one directive unlike v3 which used three directives):
```
@import "tailwindcss";
@source "./";
```

This method enables Tailwind's base styles, component classes, and utility classes in your project. Here's what each directive does:

- @tailwind base; → Imports Tailwind’s preflight styles (a minimal CSS reset).
- @tailwind components; → Imports any custom component classes defined in @layer components.
- @tailwind utilities; → Imports all utility classes (e.g., flex, text-center, mt-4).

5. Setup command to build and monitor process
At package.json scripts:
```
  "scripts": {
    "build": "npx postcss ./public/index.css -o ./public/styles.css --watch",
    "test": "echo \"Error: no test specified\" && exit 1"
  },
```

^ Notice that the index.css is passed into Postcss for watching and transformation. Postcss's tailwind plugin knows how to expand the @tailwind directives inside index.css into css rules (and particularly with the tailwind utilities directive, will cherrypick which classes are actually expanded based on which tailwind classes are used in the html files - and knows to scan the files patterned in tailwind.config.js). 

The css is expanded into styles.css per the Postcss npm script. Autoprefixing is also applied to the final results of styles.css

Therefore, index.html needs to reference destination target style.css (NOT index.css)
```
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Document</title>
    <link href="styles.css" rel="stylesheet"/>
</head>
<body>
    <h1>Title</h1>
</body>
</html>
```

Run command to build and monitor index.css -> style.css:
```
npm run build
```

6. You can right click in VS Code -> Open Live Server (Also notice a `styles.css` got generated by the npm script's command):
![[Pasted image 20250305062859.png]]

7. Start using Tailwind in your HTML
You can insert this at the `<body>`:
```
<h1 class="text-4xl text-orange-400">Title</h1>
```


8. You will see instant changes on the web browser page, as you're changing tailwind classes in your HTML code because you've started a Live Server that performs hot reload:
![[Pasted image 20250305063326.png]]
